@@ -2,15 +2,15 @@ from gymnasium.envs.registration import register
 
 register(
     id="PyFlyt/SimpleHoverEnv-v0",
-    entry_point="PyFlyt.environments:SimpleHoverEnv",
+    entry_point="PyFlyt.gym_envs:SimpleHoverEnv",
 )
 
 register(
     id="PyFlyt/SimpleWaypointEnv-v0",
-    entry_point="PyFlyt.environments:SimpleWaypointEnv",
+    entry_point="PyFlyt.gym_envs:SimpleWaypointEnv",
 )
 
 register(
     id="PyFlyt/AdvancedGatesEnv-v0",
-    entry_point="PyFlyt.environments:AdvancedGatesEnv",
+    entry_point="PyFlyt.gym_envs:AdvancedGatesEnv",
 )
